# Generated by Django 2.2.16 on 2020-11-30 11:47

from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_skill', '0005_auto_20200619_0813'),
    ]

    def keep_old_skills_names(apps, schema_editor):
        Skills = apps.get_model('djangoldp_skill', 'Skill')

        # iterate over all objects
        for skill in Skills.objects.all():
            if skill.urlid.startswith(settings.SITE_URL):
                for attr in skill._meta.get_fields():
                    if attr.name.startswith('name_'):
                        setattr(skill, attr.name, skill.name)
                skill.save()

    operations = [
        migrations.AddField(
            model_name='skill',
            name='name_af',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_ar',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_ast',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_az',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_be',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_bg',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_bn',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_br',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_bs',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_ca',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_cs',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_cy',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_da',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_de',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_dsb',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_el',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_en',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_en_au',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_en_gb',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_eo',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_es',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_es_ar',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_es_co',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_es_mx',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_es_ni',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_es_ve',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_et',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_eu',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_fa',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_fi',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_fr',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_fy',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_ga',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_gd',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_gl',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_he',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_hi',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_hr',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_hsb',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_hu',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_hy',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_ia',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_ind',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_io',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_is',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_it',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_ja',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_ka',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_kab',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_kk',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_km',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_kn',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_ko',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_lb',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_lt',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_lv',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_mk',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_ml',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_mn',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_mr',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_my',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_nb',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_ne',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_nl',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_nn',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_os',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_pa',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_pl',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_pt',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_pt_br',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_ro',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_ru',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_sk',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_sl',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_sq',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_sr',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_sr_latn',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_sv',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_sw',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_ta',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_te',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_th',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_tr',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_tt',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_udm',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_uk',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_ur',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_vi',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_zh_hans',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='skill',
            name='name_zh_hant',
            field=models.CharField(default='', max_length=255, null=True),
        ),
        migrations.RunPython(keep_old_skills_names),
    ]



from django.contrib import admin
from djangoldp_i18n.admin import DjangoLDPI18nAdmin
from djangoldp_skill.models import Skill

class SkillAdmin(DjangoLDPI18nAdmin):
    pass

admin.site.register(Skill, SkillAdmin)
